pub struct AutomatedBackupConfig {
pub automated_backup_mode: Option<String>,
pub fixed_frequency_schedule: Option<FixedFrequencySchedule>,
pub retention: Option<Duration>,
}Expand description
The automated backup config for a cluster.
This type is not used in any activity, and only used as part of another schema.
Fields
automated_backup_mode: Option<String>Optional. The automated backup mode. If the mode is disabled, the other fields will be ignored.
fixed_frequency_schedule: Option<FixedFrequencySchedule>Optional. Trigger automated backups at a fixed frequency.
retention: Option<Duration>Optional. How long to keep automated backups before the backups are deleted. The value should be between 1 day and 365 days. If not specified, the default value is 35 days.