CrossClusterReplicationConfig

Struct CrossClusterReplicationConfig 

pub struct CrossClusterReplicationConfig {
    pub cluster_role: Option<String>,
    pub membership: Option<Membership>,
    pub primary_cluster: Option<RemoteCluster>,
    pub secondary_clusters: Option<Vec<RemoteCluster>>,
    pub update_time: Option<DateTime<Utc>>,
}
Cross cluster replication config.

This type is not used in any activity, and only used as part of another schema.

Fields

cluster_role: Option<String>

Output only. The role of the cluster in cross cluster replication.

membership: Option<Membership>

Output only. An output only view of all the member clusters participating in the cross cluster replication. This view will be provided by every member cluster irrespective of its cluster role(primary or secondary). A primary cluster can provide information about all the secondary clusters replicating from it. However, a secondary cluster only knows about the primary cluster from which it is replicating. However, for scenarios, where the primary cluster is unavailable(e.g. regional outage), a GetCluster request can be sent to any other member cluster and this field will list all the member clusters participating in cross cluster replication.

primary_cluster: Option<RemoteCluster>

Details of the primary cluster that is used as the replication source for this secondary cluster. This field is only set for a secondary cluster.

secondary_clusters: Option<Vec<RemoteCluster>>

List of secondary clusters that are replicating from this primary cluster. This field is only set for a primary cluster.

update_time: Option<DateTime<Utc>>

Output only. The last time cross cluster replication config was updated.