pub struct EncryptionInfo {
pub encryption_type: Option<String>,
pub kms_key_primary_state: Option<String>,
pub kms_key_versions: Option<Vec<String>>,
pub last_update_time: Option<DateTime<Utc>>,
}Expand description
EncryptionInfo describes the encryption information of a cluster or a backup.
This type is not used in any activity, and only used as part of another schema.
Fields
encryption_type: Option<String>Output only. Type of encryption.
kms_key_primary_state: Option<String>Output only. The state of the primary version of the KMS key perceived by the system. This field is not populated in backups.
kms_key_versions: Option<Vec<String>>Output only. KMS key versions that are being used to protect the data at-rest.
last_update_time: Option<DateTime<Utc>>Output only. The most recent time when the encryption info was updated.