pub struct GcsBackupSource {
pub uris: Option<Vec<String>>,
}Expand description
Backups stored in Cloud Storage buckets. The Cloud Storage buckets need to be the same region as the clusters.
This type is not used in any activity, and only used as part of another schema.
Fields
uris: Option<Vec<String>>Optional. URIs of the Cloud Storage objects to import. Example: gs://bucket1/object1, gs://bucket2/folder2/object2