pub struct ManagedBackupSource {
pub backup: Option<String>,
}Expand description
Backups that generated and managed by memorystore.
This type is not used in any activity, and only used as part of another schema.
Fields
backup: Option<String>Optional. Example: //redis.googleapis.com/projects/{project}/locations/{location}/backupCollections/{collection}/backups/{backup} A shorter version (without the prefix) of the backup name is also supported, like projects/{project}/locations/{location}/backupCollections/{collection}/backups/{backup_id} In this case, it assumes the backup is under redis.googleapis.com.