pub struct PscAutoConnection {
pub address: Option<String>,
pub connection_type: Option<String>,
pub forwarding_rule: Option<String>,
pub network: Option<String>,
pub project_id: Option<String>,
pub psc_connection_id: Option<String>,
pub psc_connection_status: Option<String>,
pub service_attachment: Option<String>,
}Expand description
Details of consumer resources in a PSC connection that is created through Service Connectivity Automation.
This type is not used in any activity, and only used as part of another schema.
Fields
address: Option<String>Output only. The IP allocated on the consumer network for the PSC forwarding rule.
connection_type: Option<String>Output only. Type of the PSC connection.
forwarding_rule: Option<String>Output only. The URI of the consumer side forwarding rule. Example: projects/{projectNumOrId}/regions/us-east1/forwardingRules/{resourceId}.
network: Option<String>Required. The consumer network where the IP address resides, in the form of projects/{project_id}/global/networks/{network_id}.
project_id: Option<String>Required. The consumer project_id where the forwarding rule is created from.
psc_connection_id: Option<String>Output only. The PSC connection id of the forwarding rule connected to the service attachment.
psc_connection_status: Option<String>Output only. The status of the PSC connection. Please note that this value is updated periodically. Please use Private Service Connect APIs for the latest status.
service_attachment: Option<String>Output only. The service attachment which is the target of the PSC connection, in the form of projects/{project-id}/regions/{region}/serviceAttachments/{service-attachment-id}.