pub struct RemoteCluster {
pub cluster: Option<String>,
pub uid: Option<String>,
}Expand description
Details of the remote cluster associated with this cluster in a cross cluster replication setup.
This type is not used in any activity, and only used as part of another schema.
Fields
cluster: Option<String>Output only. The full resource path of the remote cluster in the format: projects//locations//clusters/
uid: Option<String>Output only. The unique identifier of the remote cluster.